@@ -1,10 +1,6 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-@author: singhmnprt01@gmail.com
-
-customdnn Copyright (C) 2020 singhmnprt01@gmail.com
-"""
+# Authors: Manpreet Singh <singhmnprt01@gmail.com>
+# customdnn Copyright (C) 2020 singhmnprt01@gmail.com  
+# License: GNU GENERAL PUBLIC LICENSE
 
 import numpy as np
 import pandas as pd
@@ -15,22 +11,6 @@ from sklearn.model_selection import train_test_split
 import sys
 import warnings
 
-"""
-The entire code is designed using NumPy.
-
-It takes user inputs as dataset (x and y) and other network designing inputs namely:-
-> learning_rate ---- The rate of learning at which the gradient steps will be taken to minimise the cost
-> beta1         ---- Beta constant for Gradient Descent Momentum Optimisation Algorithm
-> beta2         ---- Beta constant for Root Mean Square prop Optimisation Algorithm
-> batch_size    ---- To create customised mini-batches to amplify the processing and improve model accuracy/generalisation/learning.
-> network_size  ---- A custom variable to design the number of layer of your network. It is exclusive of input and output layer
-> gradient      ---- Gradient Descent Optimisation algorithm choosing field. You can input any of the following three :-
-        * GDM        - Gradient Descent Momentum
-        * RMSprop    - Room Mean Square Prop
-        * Adam       - Adaptive Momentum Estimation
-> epoch_num     ---- Number of epochs/iterations for the network. 
-
-"""
 
 
 class SplitData:
@@ -40,16 +20,18 @@ class SplitData:
 
     """
 
-    def split_train_test(self, x, y, test_percentage):
+    def split_train_test(self,x, y, test_percentage):
         """
-        x - The feature dataset as a DATA FRAME
-        y - Target variable as a DATA FRAME
-        test_percentage - percentage of total data to be used as test. Enter an integer value.
-        (if test_percentage is 20, it says that 20% data will test and 80% will be train)
-
-        The function returns 4 values (matrices):-
-        x_train, x_test, y_train, y_test
-
+         Parameters
+        ----------
+        x : dataframe
+            Input feature set
+            
+        y : dataframe(0,1)
+            Target variable
+            
+        test_percentage: int 
+            Percentage of total data to be used as test
         """
 
         test_ratio = test_percentage/100
@@ -96,7 +78,7 @@ class TrainingDeepNetwork:
 
         num_min_batches = int(np.floor(u/mini_batch_size))
 
-        for k in range(0, num_min_batches):
+        for k in range(num_min_batches):
             mini_batch_x = shuffled_x[:, k *
                                       mini_batch_size:(k+1)*mini_batch_size]
             mini_batch_y = shuffled_y[:, k *
@@ -148,7 +130,7 @@ class TrainingDeepNetwork:
 
         """
         count = 100
-        i = 0
+        prog_bar = 0
         num_batches = len(mini_batches)
         alpha = learning_rate
         cost_epoch_array = []
@@ -159,7 +141,7 @@ class TrainingDeepNetwork:
         for epoch in range(1, epoch_num+1):
             cost = 0
 
-            for num in range(0, num_batches):
+            for num in range(num_batches):
 
                 x_min = mini_batches[num][0]
                 y_min = mini_batches[num][1]
@@ -195,7 +177,7 @@ class TrainingDeepNetwork:
                 sys.stdout.write('|%s%s%s| %d%%' % (
                     unitColor, '\033[7m' + ' '*20 + 'COMPLETE!' + ' '*21 + ' \033[27m', endColor, 100))
 
-            i += 1
+            prog_bar += 1
 
         return (cost_epoch_array, cost_array, auc_array, Z_all, A_all, dZ_all, dW_all, Vdw, Vdb, param)
 
@@ -402,20 +384,41 @@ class TrainingDeepNetwork:
         """
         This is the main fucntion of the class which controls other paramount functions, process user input, 
         display cost function graphs and returns trained  set of weight and bias parameters.
-
-
-        It takes user inputs as dataset (x and y) and other network designing inputs namely:-
-        > learning_rate ---- The rate of learning at which the gradient steps will be taken to minimise the cost
-        > beta1         ---- Beta constant for Gradient Descent Momentum Optimisation Algorithm
-        > beta2         ---- Beta constant for Root Mean Square prop Optimisation Algorithm
-        > batch_size    ---- To create customised mini-batches to amplify the processing and improve model accuracy/generalisation/learning.
-        > network_size  ---- A custom variable to design the number of layer of your network. It is exclusive of input and output layer
-        > gradient      ---- Gradient Descent Optimisation algorithm choosing field. You can input any of the following three :-
-              * GDM        - Gradient Descent Momentum
-              * RMSprop    - Room Mean Square Prop
-              * Adam       - Adaptive Momentum Estimation
-        > epoch_num     ---- Number of epochs/iterations for the network. 
-
+        
+        Parameters
+        ----------
+        x : numpy array
+            Input feature set
+            
+        y : numpy array
+            Target variable
+            
+        learning_rate : float, default = .001
+            The rate of learning at which the gradient steps will be taken to minimise the cost
+            
+        beta1 : float, default = .9
+            Beta constant for Gradient Descent Momentum Optimisation Algorithm
+            
+        beta2 : float, default = .999
+            Beta constant for Root Mean Square prop Optimisation Algorithm
+            
+        batch_size : int, default = 32
+            To create customised mini-batches to amplify the processing and improve model accuracy/generalisation/learning.
+            
+        network_size : int, default = 3
+            A custom variable to design the number of layer of your network. It is exclusive of input and output layer
+            
+        gradient : string, default = "Adam"      
+            Gradient Descent Optimisation algorithm choosing field. You can input any of the following three optimizers :-
+                  GDM : Gradient Descent Momentum
+                  RMSprop : Room Mean Square Prop
+                  Adam : Adaptive Momentum Estimation
+                  
+        epoch_num : int, default = 1000
+            Number of epochs/iterations for the network. 
+          
+        dropout_percentage : int, default = 70
+            Percent of neurons to be fused.
         """
 
         layer_nn = []
